==> dcoupon_sdk_flutter_package-5.1.0.tar.gz: lib/src/config_reader.dart <==
import 'dart:convert';

import 'package:dio/dio.dart';

abstract class ConfigReader {
  static String get languageCode => _languageCode;
  static late String _languageCode;

  static String? get userJwt => _userJwt;
  static String? _userJwt;

  static String? get clientDomain => _clientDomain;
  static String? _clientDomain;

  static String? get clientCountry => _clientCountry;
  static String? _clientCountry;

  static String? get clientApiToken => _clientApiToken;
  static String? _clientApiToken;

  static String? get clientSecretKey => _clientSecretKey;
  static String? _clientSecretKey;

  static int get dateOffset => _dateOffset;
  static int _dateOffset = 0;

  static List<Interceptor> get dioInterceptors => _dioInterceptors;
  static List<Interceptor> _dioInterceptors = [];

  static void init(String contents) {
    try {
      if (contents.isEmpty) {
        throw new Exception('contents can not be empty');
      }
      // decode the json
      final json = jsonDecode(contents);

      _clientDomain = json['com.dcoupon.sdk.ClientDomain'];
      _clientCountry = json['com.dcoupon.sdk.ClientCountry'];
      _clientApiToken = json['com.dcoupon.sdk.ClientToken'];
      _clientSecretKey = json['com.dcoupon.sdk.ClientSecretKey'];
    } catch (ex) {
      print('loadAsJsonString: ' + ex.toString());
      return null;
    }
  }

  static void setDioInterceptors(List<Interceptor> dioInterceptors) {
    _dioInterceptors = dioInterceptors;
  }

  static void setLanguageCode(String languageCode) {
    _languageCode = languageCode;
  }

  static void setUserJwt(String? jwt) {
    _userJwt = jwt;
  }

  static void setDateOffset(int dateOffset) {
    _dateOffset = dateOffset;
  }

  /// Returns if the app is configured properly
  static bool isSetUp() {
    var message = <String>[];
    if (_clientApiToken == null || _clientApiToken!.isEmpty) {
      message.add("com.dcoupon.sdk.ClientToken");
    }
    if (_clientSecretKey == null || _clientSecretKey!.isEmpty) {
      message.add("com.dcoupon.sdk.ClientSecretKey");
    }
    if (_clientCountry == null || _clientCountry!.isEmpty) {
      message.add("com.dcoupon.sdk.ClientCountry");
    }
    if (_clientDomain == null || _clientDomain!.isEmpty) {
      message.add("com.dcoupon.sdk.ClientDomain");
    } else {
      if (!(_clientDomain == "local" ||
          _clientDomain == "test" ||
          _clientDomain == "dev" ||
          _clientDomain == "dcoupon.eu" ||
          _clientDomain == "dcoupon.com"))
        message.add("com.dcoupon.sdk.ClientDomain not allowed");
    }
    if (message.isNotEmpty) {
      print("Missed mandatory parameter/s:");
      message.forEach((str) {
        print(str);
      });
      return false;
    } else {
      return true;
    }
  }
}

==> dcoupon_sdk_flutter_package-7.0.1.tar.gz: lib/src/config_reader.dart <==
import 'dart:convert';

import 'package:dio/dio.dart';

abstract class ConfigReader {
  static String? get webOrigin => _webOrigin;
  static String? _webOrigin;

  static String? get userJwt => _userJwt;
  static String? _userJwt;

  static String? get clientDomain => _clientDomain;
  static String? _clientDomain;

  static String? get clientCountry => _clientCountry;
  static String? _clientCountry;

  static String? get clientApiToken => _clientApiToken;
  static String? _clientApiToken;

  static String? get clientSecretKey => _clientSecretKey;
  static String? _clientSecretKey;

  static int get dateOffset => _dateOffset;
  static int _dateOffset = 0;

  static List<Interceptor> get dioInterceptors => _dioInterceptors;
  static List<Interceptor> _dioInterceptors = [];

  static void init(String contents) {
    try {
      if (contents.isEmpty) {
        throw new Exception('contents can not be empty');
      }
      // decode the json
      final json = jsonDecode(contents);

      _clientDomain = json['com.dcoupon.sdk.ClientDomain'];
      _clientCountry = json['com.dcoupon.sdk.ClientCountry'];
      _clientApiToken = json['com.dcoupon.sdk.ClientToken'];
      _clientSecretKey = json['com.dcoupon.sdk.ClientSecretKey'];
    } catch (ex) {
      print('loadAsJsonString: ' + ex.toString());
      return null;
    }
  }

  static void setDioInterceptors(List<Interceptor> dioInterceptors) {
    _dioInterceptors = dioInterceptors;
  }

  static void setWebOrigin(String? webOrigin) {
    _webOrigin = webOrigin;
  }

  static void setUserJwt(String? jwt) {
    _userJwt = jwt;
  }

  static void setDateOffset(int dateOffset) {
    _dateOffset = dateOffset;
  }

  /// Returns if the app is configured properly
  static bool isSetUp() {
    var message = <String>[];
    if (_clientApiToken == null || _clientApiToken!.isEmpty) {
      message.add("com.dcoupon.sdk.ClientToken");
    }
    if (_clientSecretKey == null || _clientSecretKey!.isEmpty) {
      message.add("com.dcoupon.sdk.ClientSecretKey");
    }
    if (_clientCountry == null || _clientCountry!.isEmpty) {
      message.add("com.dcoupon.sdk.ClientCountry");
    }
    if (_clientDomain == null || _clientDomain!.isEmpty) {
      message.add("com.dcoupon.sdk.ClientDomain");
    } else {
      if (!(_clientDomain == "local" ||
          _clientDomain == "test" ||
          _clientDomain == "dev" ||
          _clientDomain == "dcoupon.eu" ||
          _clientDomain == "dcoupon.com"))
        message.add("com.dcoupon.sdk.ClientDomain not allowed");
    }
    if (message.isNotEmpty) {
      print("Missed mandatory parameter/s:");
      message.forEach((str) {
        print(str);
      });
      return false;
    } else {
      return true;
    }
  }
}
